@@ -143,7 +143,7 @@ The SPVM::Builder::LibInfo class has methods to manipulate library information f
   my $config = $lib_info->config;
   $lib_info->config($config);
 
-Gets and sets the C<config> field, a L<SPVM::Builder::Config> object.
+Gets and sets the C<config> field, an L<SPVM::Builder::Config> object.
 
 =head2 name
 
@@ -219,7 +219,7 @@ Return Value Examples:
 
   my $lib_name = $lib_info->to_string;
 
-Returns the L</"name"> field.
+Returns L</"name"> field.
 
 =head1 Operators
 
@@ -235,7 +235,7 @@ Always true.
 
   my $lib_name = "$lib_info";
 
-Alias for the L</"to_string"> method.
+Alias for L</"to_string"> method.
 
 =head1 Copyright & License
 
